==> vuejs-table-component-1.0.0.tgz: package/README.md <==
# vuejs-table-component

[![npm](https://img.shields.io/npm/v/vuejs-table-component.svg)](https://www.npmjs.com/package/vuejs-table-component)
[![npm](https://img.shields.io/npm/dt/vuejs-table-component.svg)](https://www.npmjs.com/package/vuejs-table-component)
[![npm](https://img.shields.io/npm/dm/vuejs-table-component.svg)](https://www.npmjs.com/package/vuejs-table-component)
[![Build Status](https://travis-ci.org/kevinongko/vuejs-table-component.svg?branch=master)](https://travis-ci.org/kevinongko/vuejs-table-component)
[![Codecov](https://img.shields.io/codecov/c/github/kevinongko/vuejs-table-component.svg)](https://codecov.io/gh/kevinongko/vuejs-table-component)
[![npm](https://img.shields.io/npm/l/vuejs-table-component.svg)](http://opensource.org/licenses/MIT)

Input field component to display a formatted currency value based on [Vue](https://vuejs.org/).

[Live Demo](https://kevinongko.github.io/vuejs-table-component/)

**Works with Vue 2.***

## Installation

### Install via CDN
```html
<script src="https://unpkg.com/accounting-js"></script>
<script src="https://unpkg.com/vue"></script>
<script src="https://unpkg.com/vuejs-table-component"></script>

<script>
  Vue.use(Datatable.default)
</script>
```
### Install via NPM
```sh
$ npm install vuejs-table-component --save
```

#### Register as Component
```js
import Vue from 'vue'
import Datatable from 'vuejs-table-component'

export default {
  name: 'App',

  components: {
    Datatable
  }
}
```

#### Register as Plugin
```js
import Vue from 'vue'
import Datatable from 'vuejs-table-component'

Vue.use(Datatable)
```

## Usage

![screen shot 2016-12-08 at 2 19 31 pm](https://cloud.githubusercontent.com/assets/15880638/21001265/f2322438-bd51-11e6-8985-f31a45702484.png)

### Quick example

```vue
<template>
  <datatable currency="$" separator="," v-model="price"></vuejs-table-component>
</template>

<script>
import Datatable from 'vuejs-table-component'

export default {
  name: 'App',

  components: {
    Datatable
  },

  data: () => ({
    price: ''
  }),
}
</script>
```

### Currency symbol

Set the `currency` prop to add a currency symbol within the input.

```vue
<vuejs-table-component currency="$"></vuejs-table-component>
```

### Minimum & maximum constraint

Limit the minimum and maximum value by using `min` and `max` props.

- `min` defaults to `0`.
- `min` and `max` accept `String` or `Number` values.

```vue
<vuejs-table-component v-bind:min="2000" v-bind:max="10000"></vuejs-table-component>
```

### Disable/enable negative values

`minus` defaults to `false` (no negative numbers).

```vue
<vuejs-table-component v-bind:minus="false"></vuejs-table-component>
```

### Enable decimal precision

By default the decimal value is disabled. To use decimals in the value, add the `precision` prop.
- `precision` accept a `String` or `Number` numeric value.

```vue
<vuejs-table-component v-bind:precision="2"></vuejs-table-component>
```

### Thousands separator
- Default thousand separator's symbol is `,`.
- Use the `separator` prop to change the thousands separator.
- `separator` only accepts `space`, `,` or `.`.
- When using the `.` or `space` as thousand separator, the decimal separator will be `,`.

```vue
<vuejs-table-component separator="."></vuejs-table-component>
```

### Input placeholder when empty
```vue
<vuejs-table-component placeholder="only number allowed"></vuejs-table-component>
```

### Value when empty
By default, when you clean the input the value is set to `0`. You can change this value to fit your needs.
```vue
<vuejs-table-component :empty-value="1"></vuejs-table-component>
```

## Props
|Props|Description|Required|Type|Default|
|-----|-----------|--------|----|-------|
|currency|Currency prefix|false|String|-|
|currency-symbol-position|Position of the symbol (accepted values: `prefix` or `suffix`)|false|String|`prefix`|
|max|Maximum value allowed|false|Number|9007199254740991|
|min|Minimum value allowed|false|Number|-9007199254740991|
|minus|Enable/disable negative values|false|Boolean|`false`|
|placeholder|Input placeholder|false|String|-|
|empty-value|Value when input is empty|false|Number|0|
|precision|Number of decimals|false|Number|-|
|separator|Thousand separator symbol (accepts `space`, `.` or `,`)|false|String|`,`|
|decimal-separator|Custom decimal separator|false|String|-|
|thousand-separator|Custom thousand separator|false|String|-|
|read-only|Hide input field and show the value as text|false|Boolean|false|
|read-only-class|Class for read-only element|false|String|''|

## License

Vue-Numeric is open-sourced software licensed under the [MIT license](http://opensource.org/licenses/MIT)

==> vuejs-table-component-1.0.10.tgz: package/README.md <==
# vuejs-table-component

[![npm](https://img.shields.io/npm/v/vuejs-table-component.svg)](https://www.npmjs.com/package/vuejs-table-component)
[![npm](https://img.shields.io/npm/dt/vuejs-table-component.svg)](https://www.npmjs.com/package/vuejs-table-component)
[![npm](https://img.shields.io/npm/dm/vuejs-table-component.svg)](https://www.npmjs.com/package/vuejs-table-component)
[![Build Status](https://travis-ci.org/kevinongko/vuejs-table-component.svg?branch=master)](https://travis-ci.org/kevinongko/vuejs-table-component)
[![Codecov](https://img.shields.io/codecov/c/github/kevinongko/vuejs-table-component.svg)](https://codecov.io/gh/kevinongko/vuejs-table-component)
[![npm](https://img.shields.io/npm/l/vuejs-table-component.svg)](http://opensource.org/licenses/MIT)

A vue component for rendering datatables. With customizable sorting and searching capabilities.

[Live Demo](https://kevinongko.github.io/vuejs-table-component/)

**Works with Vue 2.***

## Installation

### Install via CDN
```html
<script src="https://unpkg.com/accounting-js"></script>
<script src="https://unpkg.com/vue"></script>
<script src="https://unpkg.com/vuejs-table-component"></script>

<script>
  Vue.use(Datatable.default)
</script>
```
### Install via NPM
```sh
$ npm install vuejs-table-component --save
```

#### Register as Component
```js
import Vue from 'vue'
import Datatable from 'vuejs-table-component'

export default {
  name: 'App',

  components: {
    Datatable
  }
}
```

#### Register as Plugin
```js
import Vue from 'vue'
import Datatable from 'vuejs-table-component'

Vue.use(Datatable)
```

## Usage


### Quick example

```vue
<template>
  <datatable columns="columns" dataset="rows"></datatable>
</template>

<script>
import Datatable from 'vuejs-table-component'

export default {
  name: 'App',

  components: {
    Datatable
  },

  data: () => ({
    price: ''
  }),
}
</script>

## Props
|Props|Description|Required|Type|Default|
|-----|-----------|--------|----|-------|
|columns|Corresponding columns of the table|true|Array|-|
|dataset|Data to be used for pupulating the table|true|Array|-|
|perpage|List of page sizes|false|Number|9007199254740991|
|search|Minimum value allowed|false|Number|-9007199254740991|
|indices|Enable/disable negative values|false|Boolean|`false`|

## License
